@@ -1,5 +1,6 @@
 /*
  * Copyright © 2017-2019 Red Hat, Inc
+ * Copyright © 2020 Harald Sitter <sitter@kde.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,14 +31,17 @@
 #include <QStandardPaths>
 #include <QSettings>
 
+#include <KApplicationTrader>
 #include <KProcess>
+#include <KService>
 #include <kdeclarative/kdeclarative.h>
 
-AppChooserDialog::AppChooserDialog(const QStringList &choices, const QString &defaultApp, const QString &fileName, QDialog *parent, Qt::WindowFlags flags)
+AppChooserDialog::AppChooserDialog(const QStringList &choices, const QString &defaultApp, const QString &fileName, const QString &mimeName, QDialog *parent, Qt::WindowFlags flags)
     : QDialog(parent, flags)
     , m_dialog(new Ui::AppChooserDialog)
     , m_defaultChoices(choices)
     , m_defaultApp(defaultApp)
+    , m_mimeName(mimeName)
 {
     m_dialog->setupUi(this);
 
@@ -53,16 +57,18 @@ AppChooserDialog::AppChooserDialog(const QStringList &choices, const QString &de
     AppFilterModel *filterModel = new AppFilterModel(this);
     filterModel->setSourceModel(m_model);
 
-    m_dialog->quickWidget->rootContext()->setContextProperty(QStringLiteral("myModel"), filterModel);
-    m_dialog->quickWidget->rootContext()->setContextProperty(QStringLiteral("fileName"), fileName);
-    m_dialog->quickWidget->rootContext()->setContextProperty(QStringLiteral("defaultApp"), defaultApp);
+    auto *data = new AppChooserData(this);
+    data->setFileName(fileName);
+    data->setDefaultApp(defaultApp);
+
+    qmlRegisterSingletonInstance<AppFilterModel>("org.kde.xdgdesktopportal", 1, 0, "AppModel", filterModel);
+    qmlRegisterSingletonInstance<AppChooserData>("org.kde.xdgdesktopportal", 1, 0, "AppChooserData", data);
     m_dialog->quickWidget->setClearColor(Qt::transparent);
     m_dialog->quickWidget->setResizeMode(QQuickWidget::SizeRootObjectToView);
     m_dialog->quickWidget->setSource(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("xdg-desktop-portal-kde/qml/AppChooserDialog.qml"))));
 
-    QObject *rootItem = m_dialog->quickWidget->rootObject();
-    connect(rootItem, SIGNAL(openDiscover()), this, SLOT(onOpenDiscover()));
-    connect(rootItem, SIGNAL(applicationSelected(QString)), this, SLOT(onApplicationSelected(QString)));
+    connect(data, &AppChooserData::openDiscover, this, &AppChooserDialog::onOpenDiscover);
+    connect(data, &AppChooserData::applicationSelected, this, &AppChooserDialog::onApplicationSelected);
 
     setWindowTitle(i18n("Open with..."));
 }
@@ -85,7 +91,11 @@ void AppChooserDialog::onApplicationSelected(const QString& desktopFile)
 
 void AppChooserDialog::onOpenDiscover()
 {
-    KProcess::startDetached(QStringLiteral("plasma-discover"));
+    QStringList args;
+    if (!m_mimeName.isEmpty()) {
+        args << QStringLiteral("--mime") << m_mimeName;
+    }
+    KProcess::startDetached(QStringLiteral("plasma-discover"), args);
 }
 
 void AppChooserDialog::updateChoices(const QStringList &choices)
@@ -202,6 +212,33 @@ bool AppFilterModel::lessThan(const QModelIndex &left, const QModelIndex &right)
     return QString::localeAwareCompare(leftName, rightName) > 0;
 }
 
+QString AppChooserData::defaultApp() const
+{
+    return m_defaultApp;
+}
+
+void AppChooserData::setDefaultApp(const QString &defaultApp)
+{
+    m_defaultApp = defaultApp;
+    Q_EMIT defaultAppChanged();
+}
+
+AppChooserData::AppChooserData(QObject *parent)
+    : QObject(parent)
+{
+}
+
+QString AppChooserData::fileName() const
+{
+    return m_fileName;
+}
+
+void AppChooserData::setFileName(const QString &fileName)
+{
+    m_fileName = fileName;
+    Q_EMIT fileNameChanged();
+}
+
 AppModel::AppModel(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -269,40 +306,25 @@ int AppModel::rowCount(const QModelIndex &parent) const
 
 QHash<int, QByteArray> AppModel::roleNames() const
 {
-    QHash<int, QByteArray> roles = QAbstractListModel::roleNames();
-    roles[ApplicationNameRole] = "ApplicationName";
-    roles[ApplicationIconRole] = "ApplicationIcon";
-    roles[ApplicationDesktopFileRole] = "ApplicationDesktopFile";
-    roles[ApplicationCategoryRole] = "ApplicationCategory";
-
-    return roles;
+    return {
+        {ApplicationNameRole, QByteArrayLiteral("applicationName")},
+        {ApplicationIconRole, QByteArrayLiteral("applicationIcon")},
+        {ApplicationDesktopFileRole, QByteArrayLiteral("applicationDesktopFile")},
+        {ApplicationCategoryRole, QByteArrayLiteral("applicationCategory")}
+    };
 }
 
 void AppModel::loadApplications()
 {
-    for (const QString &location : QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation)) {
-        QDir dir(location);
-        for (QString &entry : dir.entryList(QStringList({QStringLiteral("*.desktop")}), QDir::Files, QDir::Name)) {
-            QString applicationIcon;
-            QString applicationName;
-
-            QSettings settings(QStringLiteral("%1/%2").arg(dir.path()).arg(entry), QSettings::IniFormat);
-            settings.beginGroup(QStringLiteral("Desktop Entry"));
-            if (settings.contains(QStringLiteral("X-GNOME-FullName"))) {
-                applicationName = settings.value(QStringLiteral("X-GNOME-FullName")).toString();
-            } else {
-                applicationName = settings.value(QStringLiteral("Name")).toString();
-            }
-            applicationIcon = settings.value(QStringLiteral("Icon")).toString();
-
-            const QString desktopFileWithoutSuffix = entry.remove(QStringLiteral(".desktop"));
-            if (applicationName.isEmpty() || applicationIcon.isEmpty())
-                continue;
-
-            ApplicationItem appItem(applicationName, applicationIcon, desktopFileWithoutSuffix);
-
-            if (!m_list.contains(appItem))
-                m_list.append(appItem);
+    const KService::List appServices = KApplicationTrader::query([](const KService::Ptr &service) -> bool {
+         return service->isValid() && !service->noDisplay() /* includes platform and desktop considerations */;
+    });
+    for (const KService::Ptr &service : appServices) {
+        const QString fullName = service->property(QStringLiteral("X-GNOME-FullName"), QVariant::String).toString();
+        const QString name = fullName.isEmpty() ? service->name() : fullName;
+        ApplicationItem appItem(name, service->icon(), service->desktopEntryName());
+        if (!m_list.contains(appItem)) {
+            m_list.append(appItem);
         }
     }
 }
