@@ -59,8 +59,9 @@ private:
 class AppFilterModel : public QSortFilterProxyModel
 {
     Q_OBJECT
-    Q_PROPERTY(bool showOnlyPreferredApps READ showOnlyPreferredApps WRITE setShowOnlyPrefferedApps)
-    Q_PROPERTY(QString filter READ filter WRITE setFilter)
+    Q_PROPERTY(bool showOnlyPreferredApps READ showOnlyPreferredApps WRITE setShowOnlyPrefferedApps NOTIFY showOnlyPreferredAppsChanged)
+    Q_PROPERTY(QString filter READ filter WRITE setFilter NOTIFY filterChanged)
+
 public:
     explicit AppFilterModel(QObject *parent = nullptr);
     ~AppFilterModel() override;
@@ -71,6 +72,10 @@ public:
     void setFilter(const QString &text);
     QString filter() const;
 
+Q_SIGNALS:
+    void showOnlyPreferredAppsChanged();
+    void filterChanged();
+
 protected:
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
     bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
@@ -80,6 +85,30 @@ private:
     QString m_filter;
 };
 
+class AppChooserData : public QObject {
+    Q_OBJECT
+    Q_PROPERTY(QString fileName READ fileName WRITE setFileName NOTIFY fileNameChanged)
+    Q_PROPERTY(QString defaultApp READ defaultApp WRITE setDefaultApp NOTIFY defaultAppChanged)
+
+public:
+    AppChooserData(QObject *parent = nullptr);
+
+    QString fileName() const;
+    void setFileName(const QString &fileName);
+    Q_SIGNAL void fileNameChanged();
+
+    QString defaultApp() const;
+    void setDefaultApp(const QString &defaultApp);
+    Q_SIGNAL void defaultAppChanged();
+
+    Q_SIGNAL void applicationSelected(const QString &desktopFile);
+    Q_SIGNAL void openDiscover();
+
+private:
+    QString m_defaultApp;
+    QString m_fileName;
+};
+
 class AppModel : public QAbstractListModel
 {
     Q_OBJECT
@@ -110,7 +139,8 @@ class AppChooserDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit AppChooserDialog(const QStringList &choices, const QString &defaultApp, const QString &fileName, QDialog *parent = nullptr, Qt::WindowFlags flags = {});
+    explicit AppChooserDialog(const QStringList &choices, const QString &defaultApp, const QString &fileName,
+                              const QString &mimeName = QString(), QDialog *parent = nullptr, Qt::WindowFlags flags = {});
     ~AppChooserDialog();
 
     void updateChoices(const QStringList &choices);
@@ -119,6 +149,7 @@ public:
 private Q_SLOTS:
     void onApplicationSelected(const QString &desktopFile);
     void onOpenDiscover();
+
 private:
     Ui::AppChooserDialog *m_dialog;
 
@@ -126,6 +157,7 @@ private:
     QStringList m_defaultChoices;
     QString m_defaultApp;
     QString m_selectedApplication;
+    QString m_mimeName;
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_APPCHOOSER_DIALOG_H
