@@ -110,7 +110,7 @@ private:
                                QStringList &mimeTypeFilters, QMap<QString, FilterList> &allFilters,
                                QString &selectedMimeTypeFilter);
 
-    bool isMobile() const;
+    static bool isMobile();
 
     MobileFileDialog *m_mobileFileDialog;
 };
