@@ -55,10 +55,15 @@ uint RemoteDesktopPortal::CreateSession(const QDBusObjectPath &handle,
         return 2;
     }
 
-    connect(session, &Session::closed, [this] () {
-        WaylandIntegration::stopStreaming();
+    connect(session, &Session::closed, [] () {
+        WaylandIntegration::stopAllStreaming();
     });
 
+    if (!WaylandIntegration::isStreamingAvailable()) {
+        qCWarning(XdgDesktopPortalKdeRemoteDesktop) << "zkde_screencast_unstable_v1 does not seem to be available";
+        return 2;
+    }
+
     return 0;
 }
 
@@ -128,7 +133,7 @@ uint RemoteDesktopPortal::Start(const QDBusObjectPath &handle,
 
     if (remoteDesktopDialog->exec()) {
         if (session->screenSharingEnabled()) {
-            if (!WaylandIntegration::startStreaming(remoteDesktopDialog->selectedScreens().first())) {
+            if (!WaylandIntegration::startStreamingOutput(remoteDesktopDialog->selectedScreens().first(), Screencasting::Hidden)) {
                 return 2;
             }
 
