@@ -22,11 +22,13 @@
 #define XDG_DESKTOP_PORTAL_KDE_SCREENCHOOSER_DIALOG_H
 
 #include <QDialog>
+#include "screencast.h"
 
 namespace Ui
 {
 class ScreenChooserDialog;
 }
+class QItemSelection;
 
 class ScreenChooserDialog : public QDialog
 {
@@ -35,9 +37,15 @@ public:
     ScreenChooserDialog(const QString &appName, bool multiple, QDialog *parent = nullptr, Qt::WindowFlags flags = {});
     ~ScreenChooserDialog();
 
+    void setSourceTypes(ScreenCastPortal::SourceTypes types);
+
     QList<quint32> selectedScreens() const;
+    QList<QByteArray> selectedWindows() const;
 
 private:
+    void selectionChanged(const QItemSelection &selected);
+
+    const bool m_multiple;
     Ui::ScreenChooserDialog *m_dialog;
 };
 
